@@ -1,5 +1,24 @@
 from .base import BaseModel, ObjectListModel
 
+class ExtraInformatie(BaseModel):
+    
+    def __init__(self,
+        text=None,
+        taal=None,
+        taal_display=None
+    ):
+        
+        super().__init__()
+        
+        self.text = text
+        self.taal = taal
+        self.taal_display = taal_display    
+
+class ExtraInformatieList(ObjectListModel):
+    
+    def __init__(self):
+        super().__init__(list=[], listObject=ExtraInformatie)
+
 class Prijscategorie(BaseModel):
     
     def __init__(self,
@@ -39,6 +58,26 @@ class ArtikelFotos(ObjectListModel):
     def __init__(self):
         super().__init__(list=[], listObject=ArtikelFoto)
 
+class ArtikelCategorie(BaseModel):
+    
+    def __init__(self,
+        id=None,
+        naam=None,
+        hoofdcategorie=None,
+        hoofdcategorie_id=None
+    ):
+        
+        super().__init__()
+        
+        self.id = id
+        self.naam = naam
+        self.hoofdcategorie = hoofdcategorie
+        self.hoofdcategorie_id = hoofdcategorie_id
+
+class ArtikelCategorieen(ObjectListModel):
+    def __init__(self):
+        super().__init__(list=[], listObject=ArtikelCategorie)
+
 class Artikel(BaseModel):
     
     def __init__(self,
@@ -46,7 +85,9 @@ class Artikel(BaseModel):
         naam=None,
         beschrijving=None,
         merk=None,
+        merk_id=None,
         categorie=None,
+        categorie_id=None,
         SKU=None,
         voorraad_bijhouden=None,
         op_voorraad=None,
@@ -62,6 +103,9 @@ class Artikel(BaseModel):
         fotos=None,
         prijscategorieen=None,
         EAN=None,
+        samenstellingen=None,
+        ruwe_grondstoffen=None,
+        gebruiksaanwijzingen=None
     ):
 
         super().__init__()
@@ -70,7 +114,9 @@ class Artikel(BaseModel):
         self.naam = naam
         self.beschrijving = beschrijving
         self.merk = merk
+        self.merk_id = merk_id
         self.categorie = categorie
+        self.categorie_id = categorie_id
         self.SKU = SKU
         self.voorraad_bijhouden = voorraad_bijhouden
         self.op_voorraad = op_voorraad
@@ -85,6 +131,9 @@ class Artikel(BaseModel):
         self.status = status
         self.fotos = fotos if fotos else ArtikelFotos()
         self.prijscategorieen = prijscategorieen if prijscategorieen else Prijscategorieen()
+        self.samenstellingen = samenstellingen if samenstellingen else ExtraInformatieList()
+        self.ruwe_grondstoffen = ruwe_grondstoffen if ruwe_grondstoffen else ExtraInformatieList()
+        self.gebruiksaanwijzingen = gebruiksaanwijzingen if gebruiksaanwijzingen else ExtraInformatieList()
         self.EAN = EAN if EAN else []
         
 class Artikels(ObjectListModel):
